@@ -66,7 +66,7 @@ setMethod("plot", signature(x='RasterStackBrick', y='ANY'),
 
 setMethod("plot", signature(x='RasterLayer', y='missing'), 
 
-function(x, col=rev(terrain.colors(255)), maxpixels=500000, levelplot=FALSE, newstyle=FALSE, alpha=1, ...)  {
+function(x, col=rev(terrain.colors(255)), maxpixels=500000, newstyle=FALSE, alpha=1, ...)  {
 
 		if (alpha < 1) {
 			alpha <- max(alpha, 0) * 255 + 1
@@ -75,9 +75,7 @@ function(x, col=rev(terrain.colors(255)), maxpixels=500000, levelplot=FALSE, new
 			col <- paste(substr(col, 1, 7), alpha, sep="")
 		}
 
-		if (levelplot) {
-			.levelplotraster(x, col=col, maxpixels=maxpixels, ...) 
-		} else if (length(x@legend@colortable) > 0) {
+		if (length(x@legend@colortable) > 0) {
 			.plotCT(x, maxpixels=maxpixels, ...)
 		} else if (newstyle) {
 			.plot2(x, col=col, maxpixels=maxpixels, ...)
