@@ -75,7 +75,7 @@ setMethod('predict', signature(object='Raster'),
 		
 		tr <- blockSize(predrast, n=nlayers(object)+3)
 
-		napred <- rep(NA, ncol(predrast)*tr$size )
+		napred <- matrix(rep(NA, ncol(predrast) * tr$size * nlayers(predrast)), ncol=nlayers(predrast))
 		factres	<- FALSE
 		pb <- pbCreate(tr$n,  type=progress )			
 
@@ -83,7 +83,7 @@ setMethod('predict', signature(object='Raster'),
 		
 			if (i==tr$n) {
 				ablock <- 1:(ncol(object) * tr$nrows[i])
-				napred <- rep(NA, ncol(predrast) * tr$nrows[i])
+				napred <- matrix(rep(NA, ncol(predrast) * tr$nrows[i] * nlayers(predrast)), ncol=nlayers(predrast))
 			}
 
 			rr <- firstrow + tr$row[i] - 1
@@ -115,8 +115,10 @@ setMethod('predict', signature(object='Raster'),
 			if (nrow(blockvals) == 0 ) {
 				predv <- napred
 			} else {
+	
 				predv <- fun(model, blockvals, ...)
-				
+
+		
 				if (class(predv)[1] == 'list') {
 					predv = unlist(predv)
 					if (length(predv) != nrow(blockvals)) {
@@ -127,13 +129,15 @@ setMethod('predict', signature(object='Raster'),
 				}
 				
 				if (isTRUE(dim(predv)[2] > 1)) {
-					predv = predv[ , index]
-					#predv = predv[,index, drop=FALSE]
-					#for (i in 1:ncol(predv)) {
-					#	if (is.factor(predv[,i])) {
-					#		predv[,i] <- as.integer(as.character(predv[,i]))
-					#	}
-					#}
+					predv <- predv[,index, drop=FALSE]
+					for (fi in 1:ncol(predv)) {
+						if (is.factor(predv[,fi])) {
+							predv[,fi] <- as.integer(as.character(predv[,fi]))
+						}
+					}
+					# if data.frame
+					predv <- as.matrix(predv)
+					
 				} else if (is.factor(predv)) {
 					# should keep track of this to return a factor type RasterLayer
 					factres <- TRUE
@@ -144,7 +148,7 @@ setMethod('predict', signature(object='Raster'),
 					naind <- as.vector(attr(blockvals, "na.action"))
 					if (!is.null(naind)) {
 						p <- napred
-						p[-naind] <- predv
+						p[-naind,] <- predv
 						predv <- p
 						rm(p)
 					}
@@ -153,7 +157,7 @@ setMethod('predict', signature(object='Raster'),
 
 		
 			if (filename == '') {
-				cells = cellFromRowCol(predrast, tr$row[i], 1):cellFromRowCol(predrast, tr$row[i]+tr$nrows[i]-1, ncol(predrast))
+				cells <- cellFromRowCol(predrast, tr$row[i], 1):cellFromRowCol(predrast, tr$row[i]+tr$nrows[i]-1, ncol(predrast))
 				v[cells, ] <- predv 
 			} else {
 				predrast <- writeValues(predrast, predv, tr$row[i])
@@ -166,7 +170,6 @@ setMethod('predict', signature(object='Raster'),
 			try(layerNames(predrast) <- colnames(predv), silent=TRUE)
 		}
 
-		
 		if (filename == '') {
 			predrast <- setValues(predrast, v)  # or as.vector
 		} else {
